Ethereum Types
==============

Types and utilities used by the [Ethereum Execution Layer Specification (EELS)][eels]. Includes:

- Fixed-size unsigned integers (`U256`, `U64`, etc.)
- Arbitrarily-sized unsigned integers (`Uint`.)
- Fixed-size byte sequences (`Bytes4`, `Bytes8`, etc.)
- Utilities for making/interacting with immutable dataclasses (`slotted_freezable`, `modify`.)

[eels]: https://github.com/ethereum/execution-specs
